/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   (C) 2002-2003 Dakshinamurthy K (kd@subexgroup.com)                    *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <unistd.h>
#include <stdlib.h>

#include <exception>
#include <iostream>
#include <iomanip>
#include <map>

#include <dame/utility.hpp>
#include "SelectDB.hpp"

#ifdef ORACLE
#include "dame/oradatabase.hpp"
#else
#ifdef POSTGRES
#include "dame/pgdatabase.hpp"
#else
#error "A database need to be defined"
#endif
#endif

class Mapper
{
    std::map<std::string, double>&      m ;
public:
    Mapper (std::map<std::string, double>& _m)
        : m(_m) {
    }
    int operator() (Dame::ExampleDb::emp* e) {
        m[e->GetDeptname()] = e->GetSalary() ;
    }
} ;

int
main(int argc, char *argv[])
{
    char *user = "scott", *password = "tiger", *database = "dame" ;
    Dame::DatabaseIf*   db = NULL ;

    try {
#ifdef ORACLE
        Dame::Oracle::OraDatabase db (user, password, database) ;
#else
        Dame::Postgres::PgDatabase db (user, password, database) ;
#endif
        Dame::Example::SelectDB                 edb (&db) ;
        std::map<std::string, double>           smap ;

        edb.GetSalByDept (Mapper(smap)) ;
        for (std::map<std::string, double>::iterator it = smap.begin(); it != smap.end(); ++it)
            std::cout << it->first << " " << it->second << std::endl ;
    } catch (std::exception& e) {
        std::cerr << e.what() << std::endl ;
        exit (1) ;
    }
    exit (0) ;
}
